# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FieldValue(object):
    """
    The value of a form field.
    """

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "STRING"
    VALUE_TYPE_STRING = "STRING"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "DATE"
    VALUE_TYPE_DATE = "DATE"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "TIME"
    VALUE_TYPE_TIME = "TIME"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "PHONE_NUMBER"
    VALUE_TYPE_PHONE_NUMBER = "PHONE_NUMBER"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "NUMBER"
    VALUE_TYPE_NUMBER = "NUMBER"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "INTEGER"
    VALUE_TYPE_INTEGER = "INTEGER"

    #: A constant which can be used with the value_type property of a FieldValue.
    #: This constant has a value of "ARRAY"
    VALUE_TYPE_ARRAY = "ARRAY"

    def __init__(self, **kwargs):
        """
        Initializes a new FieldValue object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.ai_vision.models.ValueTime`
        * :class:`~oci.ai_vision.models.ValueInteger`
        * :class:`~oci.ai_vision.models.ValueDate`
        * :class:`~oci.ai_vision.models.ValueNumber`
        * :class:`~oci.ai_vision.models.ValueString`
        * :class:`~oci.ai_vision.models.ValuePhoneNumber`
        * :class:`~oci.ai_vision.models.ValueArray`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value_type:
            The value to assign to the value_type property of this FieldValue.
            Allowed values for this property are: "STRING", "DATE", "TIME", "PHONE_NUMBER", "NUMBER", "INTEGER", "ARRAY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type value_type: str

        :param text:
            The value to assign to the text property of this FieldValue.
        :type text: str

        :param confidence:
            The value to assign to the confidence property of this FieldValue.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this FieldValue.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        :param word_indexes:
            The value to assign to the word_indexes property of this FieldValue.
        :type word_indexes: list[int]

        """
        self.swagger_types = {
            'value_type': 'str',
            'text': 'str',
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon',
            'word_indexes': 'list[int]'
        }
        self.attribute_map = {
            'value_type': 'valueType',
            'text': 'text',
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon',
            'word_indexes': 'wordIndexes'
        }
        self._value_type = None
        self._text = None
        self._confidence = None
        self._bounding_polygon = None
        self._word_indexes = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['valueType']

        if type == 'TIME':
            return 'ValueTime'

        if type == 'INTEGER':
            return 'ValueInteger'

        if type == 'DATE':
            return 'ValueDate'

        if type == 'NUMBER':
            return 'ValueNumber'

        if type == 'STRING':
            return 'ValueString'

        if type == 'PHONE_NUMBER':
            return 'ValuePhoneNumber'

        if type == 'ARRAY':
            return 'ValueArray'
        else:
            return 'FieldValue'

    @property
    def value_type(self):
        """
        **[Required]** Gets the value_type of this FieldValue.
        The type of data detected.

        Allowed values for this property are: "STRING", "DATE", "TIME", "PHONE_NUMBER", "NUMBER", "INTEGER", "ARRAY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The value_type of this FieldValue.
        :rtype: str
        """
        return self._value_type

    @value_type.setter
    def value_type(self, value_type):
        """
        Sets the value_type of this FieldValue.
        The type of data detected.


        :param value_type: The value_type of this FieldValue.
        :type: str
        """
        allowed_values = ["STRING", "DATE", "TIME", "PHONE_NUMBER", "NUMBER", "INTEGER", "ARRAY"]
        if not value_allowed_none_or_none_sentinel(value_type, allowed_values):
            value_type = 'UNKNOWN_ENUM_VALUE'
        self._value_type = value_type

    @property
    def text(self):
        """
        Gets the text of this FieldValue.
        The detected text of a field.


        :return: The text of this FieldValue.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this FieldValue.
        The detected text of a field.


        :param text: The text of this FieldValue.
        :type: str
        """
        self._text = text

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this FieldValue.
        The confidence score between 0 and 1.


        :return: The confidence of this FieldValue.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this FieldValue.
        The confidence score between 0 and 1.


        :param confidence: The confidence of this FieldValue.
        :type: float
        """
        self._confidence = confidence

    @property
    def bounding_polygon(self):
        """
        **[Required]** Gets the bounding_polygon of this FieldValue.

        :return: The bounding_polygon of this FieldValue.
        :rtype: oci.ai_vision.models.BoundingPolygon
        """
        return self._bounding_polygon

    @bounding_polygon.setter
    def bounding_polygon(self, bounding_polygon):
        """
        Sets the bounding_polygon of this FieldValue.

        :param bounding_polygon: The bounding_polygon of this FieldValue.
        :type: oci.ai_vision.models.BoundingPolygon
        """
        self._bounding_polygon = bounding_polygon

    @property
    def word_indexes(self):
        """
        **[Required]** Gets the word_indexes of this FieldValue.
        The indexes of the words in the field value.


        :return: The word_indexes of this FieldValue.
        :rtype: list[int]
        """
        return self._word_indexes

    @word_indexes.setter
    def word_indexes(self, word_indexes):
        """
        Sets the word_indexes of this FieldValue.
        The indexes of the words in the field value.


        :param word_indexes: The word_indexes of this FieldValue.
        :type: list[int]
        """
        self._word_indexes = word_indexes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoStreamMetadata(object):
    """
    Video information.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoStreamMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param frame_rate:
            The value to assign to the frame_rate property of this VideoStreamMetadata.
        :type frame_rate: float

        :param frame_width:
            The value to assign to the frame_width property of this VideoStreamMetadata.
        :type frame_width: int

        :param frame_height:
            The value to assign to the frame_height property of this VideoStreamMetadata.
        :type frame_height: int

        """
        self.swagger_types = {
            'frame_rate': 'float',
            'frame_width': 'int',
            'frame_height': 'int'
        }
        self.attribute_map = {
            'frame_rate': 'frameRate',
            'frame_width': 'frameWidth',
            'frame_height': 'frameHeight'
        }
        self._frame_rate = None
        self._frame_width = None
        self._frame_height = None

    @property
    def frame_rate(self):
        """
        **[Required]** Gets the frame_rate of this VideoStreamMetadata.
        Video framerate.


        :return: The frame_rate of this VideoStreamMetadata.
        :rtype: float
        """
        return self._frame_rate

    @frame_rate.setter
    def frame_rate(self, frame_rate):
        """
        Sets the frame_rate of this VideoStreamMetadata.
        Video framerate.


        :param frame_rate: The frame_rate of this VideoStreamMetadata.
        :type: float
        """
        self._frame_rate = frame_rate

    @property
    def frame_width(self):
        """
        **[Required]** Gets the frame_width of this VideoStreamMetadata.
        Width of each frame.


        :return: The frame_width of this VideoStreamMetadata.
        :rtype: int
        """
        return self._frame_width

    @frame_width.setter
    def frame_width(self, frame_width):
        """
        Sets the frame_width of this VideoStreamMetadata.
        Width of each frame.


        :param frame_width: The frame_width of this VideoStreamMetadata.
        :type: int
        """
        self._frame_width = frame_width

    @property
    def frame_height(self):
        """
        **[Required]** Gets the frame_height of this VideoStreamMetadata.
        Height of each frame.


        :return: The frame_height of this VideoStreamMetadata.
        :rtype: int
        """
        return self._frame_height

    @frame_height.setter
    def frame_height(self, frame_height):
        """
        Sets the frame_height of this VideoStreamMetadata.
        Height of each frame.


        :param frame_height: The frame_height of this VideoStreamMetadata.
        :type: int
        """
        self._frame_height = frame_height

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoSegment(object):
    """
    A sequence of frames that was (or appears to be) continuously captured for a label/object/text?.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoSegment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param start_time_offset_ms:
            The value to assign to the start_time_offset_ms property of this VideoSegment.
        :type start_time_offset_ms: int

        :param end_time_offset_ms:
            The value to assign to the end_time_offset_ms property of this VideoSegment.
        :type end_time_offset_ms: int

        """
        self.swagger_types = {
            'start_time_offset_ms': 'int',
            'end_time_offset_ms': 'int'
        }
        self.attribute_map = {
            'start_time_offset_ms': 'startTimeOffsetMs',
            'end_time_offset_ms': 'endTimeOffsetMs'
        }
        self._start_time_offset_ms = None
        self._end_time_offset_ms = None

    @property
    def start_time_offset_ms(self):
        """
        **[Required]** Gets the start_time_offset_ms of this VideoSegment.
        Video start time offset(Milliseconds).


        :return: The start_time_offset_ms of this VideoSegment.
        :rtype: int
        """
        return self._start_time_offset_ms

    @start_time_offset_ms.setter
    def start_time_offset_ms(self, start_time_offset_ms):
        """
        Sets the start_time_offset_ms of this VideoSegment.
        Video start time offset(Milliseconds).


        :param start_time_offset_ms: The start_time_offset_ms of this VideoSegment.
        :type: int
        """
        self._start_time_offset_ms = start_time_offset_ms

    @property
    def end_time_offset_ms(self):
        """
        **[Required]** Gets the end_time_offset_ms of this VideoSegment.
        Video end time offset(Milliseconds).


        :return: The end_time_offset_ms of this VideoSegment.
        :rtype: int
        """
        return self._end_time_offset_ms

    @end_time_offset_ms.setter
    def end_time_offset_ms(self, end_time_offset_ms):
        """
        Sets the end_time_offset_ms of this VideoSegment.
        Video end time offset(Milliseconds).


        :param end_time_offset_ms: The end_time_offset_ms of this VideoSegment.
        :type: int
        """
        self._end_time_offset_ms = end_time_offset_ms

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .image_feature import ImageFeature
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageClassificationFeature(ImageFeature):
    """
    The image classification parameters.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImageClassificationFeature object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.ImageClassificationFeature.feature_type` attribute
        of this class is ``IMAGE_CLASSIFICATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this ImageClassificationFeature.
            Allowed values for this property are: "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", "TEXT_DETECTION", "FACE_DETECTION", "FACE_EMBEDDING"
        :type feature_type: str

        :param max_results:
            The value to assign to the max_results property of this ImageClassificationFeature.
        :type max_results: int

        :param model_id:
            The value to assign to the model_id property of this ImageClassificationFeature.
        :type model_id: str

        """
        self.swagger_types = {
            'feature_type': 'str',
            'max_results': 'int',
            'model_id': 'str'
        }
        self.attribute_map = {
            'feature_type': 'featureType',
            'max_results': 'maxResults',
            'model_id': 'modelId'
        }
        self._feature_type = None
        self._max_results = None
        self._model_id = None
        self._feature_type = 'IMAGE_CLASSIFICATION'

    @property
    def max_results(self):
        """
        Gets the max_results of this ImageClassificationFeature.
        The maximum number of results to return.


        :return: The max_results of this ImageClassificationFeature.
        :rtype: int
        """
        return self._max_results

    @max_results.setter
    def max_results(self, max_results):
        """
        Sets the max_results of this ImageClassificationFeature.
        The maximum number of results to return.


        :param max_results: The max_results of this ImageClassificationFeature.
        :type: int
        """
        self._max_results = max_results

    @property
    def model_id(self):
        """
        Gets the model_id of this ImageClassificationFeature.
        The custom model ID.


        :return: The model_id of this ImageClassificationFeature.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this ImageClassificationFeature.
        The custom model ID.


        :param model_id: The model_id of this ImageClassificationFeature.
        :type: str
        """
        self._model_id = model_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoJob(object):
    """
    Job details for a video analysis.
    """

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a VideoJob.
    #: This constant has a value of "CANCELING"
    LIFECYCLE_STATE_CANCELING = "CANCELING"

    #: A constant which can be used with the lifecycle_details property of a VideoJob.
    #: This constant has a value of "PARTIALLY_SUCCEEDED"
    LIFECYCLE_DETAILS_PARTIALLY_SUCCEEDED = "PARTIALLY_SUCCEEDED"

    #: A constant which can be used with the lifecycle_details property of a VideoJob.
    #: This constant has a value of "COMPLETELY_FAILED"
    LIFECYCLE_DETAILS_COMPLETELY_FAILED = "COMPLETELY_FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VideoJob object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VideoJob.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VideoJob.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this VideoJob.
        :type display_name: str

        :param features:
            The value to assign to the features property of this VideoJob.
        :type features: list[oci.ai_vision.models.VideoFeature]

        :param input_location:
            The value to assign to the input_location property of this VideoJob.
        :type input_location: oci.ai_vision.models.InputLocation

        :param time_accepted:
            The value to assign to the time_accepted property of this VideoJob.
        :type time_accepted: datetime

        :param time_started:
            The value to assign to the time_started property of this VideoJob.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this VideoJob.
        :type time_finished: datetime

        :param percent_complete:
            The value to assign to the percent_complete property of this VideoJob.
        :type percent_complete: float

        :param output_location:
            The value to assign to the output_location property of this VideoJob.
        :type output_location: oci.ai_vision.models.OutputLocation

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VideoJob.
            Allowed values for this property are: "SUCCEEDED", "FAILED", "ACCEPTED", "CANCELED", "IN_PROGRESS", "CANCELING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this VideoJob.
            Allowed values for this property are: "PARTIALLY_SUCCEEDED", "COMPLETELY_FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VideoJob.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this VideoJob.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this VideoJob.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'features': 'list[VideoFeature]',
            'input_location': 'InputLocation',
            'time_accepted': 'datetime',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'percent_complete': 'float',
            'output_location': 'OutputLocation',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'features': 'features',
            'input_location': 'inputLocation',
            'time_accepted': 'timeAccepted',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'percent_complete': 'percentComplete',
            'output_location': 'outputLocation',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._features = None
        self._input_location = None
        self._time_accepted = None
        self._time_started = None
        self._time_finished = None
        self._percent_complete = None
        self._output_location = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VideoJob.
        Id of the job.


        :return: The id of this VideoJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VideoJob.
        Id of the job.


        :param id: The id of this VideoJob.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VideoJob.
        The ocid of the compartment that starts the job.


        :return: The compartment_id of this VideoJob.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VideoJob.
        The ocid of the compartment that starts the job.


        :param compartment_id: The compartment_id of this VideoJob.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this VideoJob.
        Video job display name.


        :return: The display_name of this VideoJob.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this VideoJob.
        Video job display name.


        :param display_name: The display_name of this VideoJob.
        :type: str
        """
        self._display_name = display_name

    @property
    def features(self):
        """
        **[Required]** Gets the features of this VideoJob.
        a list of document analysis features.


        :return: The features of this VideoJob.
        :rtype: list[oci.ai_vision.models.VideoFeature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this VideoJob.
        a list of document analysis features.


        :param features: The features of this VideoJob.
        :type: list[oci.ai_vision.models.VideoFeature]
        """
        self._features = features

    @property
    def input_location(self):
        """
        Gets the input_location of this VideoJob.

        :return: The input_location of this VideoJob.
        :rtype: oci.ai_vision.models.InputLocation
        """
        return self._input_location

    @input_location.setter
    def input_location(self, input_location):
        """
        Sets the input_location of this VideoJob.

        :param input_location: The input_location of this VideoJob.
        :type: oci.ai_vision.models.InputLocation
        """
        self._input_location = input_location

    @property
    def time_accepted(self):
        """
        **[Required]** Gets the time_accepted of this VideoJob.
        Job accepted time.


        :return: The time_accepted of this VideoJob.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this VideoJob.
        Job accepted time.


        :param time_accepted: The time_accepted of this VideoJob.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_started(self):
        """
        Gets the time_started of this VideoJob.
        Job started time.


        :return: The time_started of this VideoJob.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this VideoJob.
        Job started time.


        :param time_started: The time_started of this VideoJob.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this VideoJob.
        Job finished time.


        :return: The time_finished of this VideoJob.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this VideoJob.
        Job finished time.


        :param time_finished: The time_finished of this VideoJob.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this VideoJob.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :return: The percent_complete of this VideoJob.
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this VideoJob.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :param percent_complete: The percent_complete of this VideoJob.
        :type: float
        """
        self._percent_complete = percent_complete

    @property
    def output_location(self):
        """
        **[Required]** Gets the output_location of this VideoJob.

        :return: The output_location of this VideoJob.
        :rtype: oci.ai_vision.models.OutputLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this VideoJob.

        :param output_location: The output_location of this VideoJob.
        :type: oci.ai_vision.models.OutputLocation
        """
        self._output_location = output_location

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this VideoJob.
        The current state of the video job.

        Allowed values for this property are: "SUCCEEDED", "FAILED", "ACCEPTED", "CANCELED", "IN_PROGRESS", "CANCELING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VideoJob.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VideoJob.
        The current state of the video job.


        :param lifecycle_state: The lifecycle_state of this VideoJob.
        :type: str
        """
        allowed_values = ["SUCCEEDED", "FAILED", "ACCEPTED", "CANCELED", "IN_PROGRESS", "CANCELING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this VideoJob.
        Detailed status of FAILED state.

        Allowed values for this property are: "PARTIALLY_SUCCEEDED", "COMPLETELY_FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_details of this VideoJob.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this VideoJob.
        Detailed status of FAILED state.


        :param lifecycle_details: The lifecycle_details of this VideoJob.
        :type: str
        """
        allowed_values = ["PARTIALLY_SUCCEEDED", "COMPLETELY_FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_details, allowed_values):
            lifecycle_details = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VideoJob.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this VideoJob.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VideoJob.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this VideoJob.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VideoJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this VideoJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VideoJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this VideoJob.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this VideoJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        For example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this VideoJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this VideoJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        For example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this VideoJob.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Table(object):
    """
    The table extracted from a document.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Table object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param row_count:
            The value to assign to the row_count property of this Table.
        :type row_count: int

        :param column_count:
            The value to assign to the column_count property of this Table.
        :type column_count: int

        :param header_rows:
            The value to assign to the header_rows property of this Table.
        :type header_rows: list[oci.ai_vision.models.TableRow]

        :param body_rows:
            The value to assign to the body_rows property of this Table.
        :type body_rows: list[oci.ai_vision.models.TableRow]

        :param footer_rows:
            The value to assign to the footer_rows property of this Table.
        :type footer_rows: list[oci.ai_vision.models.TableRow]

        :param confidence:
            The value to assign to the confidence property of this Table.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this Table.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        """
        self.swagger_types = {
            'row_count': 'int',
            'column_count': 'int',
            'header_rows': 'list[TableRow]',
            'body_rows': 'list[TableRow]',
            'footer_rows': 'list[TableRow]',
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon'
        }
        self.attribute_map = {
            'row_count': 'rowCount',
            'column_count': 'columnCount',
            'header_rows': 'headerRows',
            'body_rows': 'bodyRows',
            'footer_rows': 'footerRows',
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon'
        }
        self._row_count = None
        self._column_count = None
        self._header_rows = None
        self._body_rows = None
        self._footer_rows = None
        self._confidence = None
        self._bounding_polygon = None

    @property
    def row_count(self):
        """
        **[Required]** Gets the row_count of this Table.
        The number of rows.


        :return: The row_count of this Table.
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """
        Sets the row_count of this Table.
        The number of rows.


        :param row_count: The row_count of this Table.
        :type: int
        """
        self._row_count = row_count

    @property
    def column_count(self):
        """
        **[Required]** Gets the column_count of this Table.
        The number of columns.


        :return: The column_count of this Table.
        :rtype: int
        """
        return self._column_count

    @column_count.setter
    def column_count(self, column_count):
        """
        Sets the column_count of this Table.
        The number of columns.


        :param column_count: The column_count of this Table.
        :type: int
        """
        self._column_count = column_count

    @property
    def header_rows(self):
        """
        **[Required]** Gets the header_rows of this Table.
        The header rows.


        :return: The header_rows of this Table.
        :rtype: list[oci.ai_vision.models.TableRow]
        """
        return self._header_rows

    @header_rows.setter
    def header_rows(self, header_rows):
        """
        Sets the header_rows of this Table.
        The header rows.


        :param header_rows: The header_rows of this Table.
        :type: list[oci.ai_vision.models.TableRow]
        """
        self._header_rows = header_rows

    @property
    def body_rows(self):
        """
        **[Required]** Gets the body_rows of this Table.
        The body rows.


        :return: The body_rows of this Table.
        :rtype: list[oci.ai_vision.models.TableRow]
        """
        return self._body_rows

    @body_rows.setter
    def body_rows(self, body_rows):
        """
        Sets the body_rows of this Table.
        The body rows.


        :param body_rows: The body_rows of this Table.
        :type: list[oci.ai_vision.models.TableRow]
        """
        self._body_rows = body_rows

    @property
    def footer_rows(self):
        """
        **[Required]** Gets the footer_rows of this Table.
        the footer rows.


        :return: The footer_rows of this Table.
        :rtype: list[oci.ai_vision.models.TableRow]
        """
        return self._footer_rows

    @footer_rows.setter
    def footer_rows(self, footer_rows):
        """
        Sets the footer_rows of this Table.
        the footer rows.


        :param footer_rows: The footer_rows of this Table.
        :type: list[oci.ai_vision.models.TableRow]
        """
        self._footer_rows = footer_rows

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this Table.
        The confidence score between 0 and 1.


        :return: The confidence of this Table.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this Table.
        The confidence score between 0 and 1.


        :param confidence: The confidence of this Table.
        :type: float
        """
        self._confidence = confidence

    @property
    def bounding_polygon(self):
        """
        **[Required]** Gets the bounding_polygon of this Table.

        :return: The bounding_polygon of this Table.
        :rtype: oci.ai_vision.models.BoundingPolygon
        """
        return self._bounding_polygon

    @bounding_polygon.setter
    def bounding_polygon(self, bounding_polygon):
        """
        Sets the bounding_polygon of this Table.

        :param bounding_polygon: The bounding_polygon of this Table.
        :type: oci.ai_vision.models.BoundingPolygon
        """
        self._bounding_polygon = bounding_polygon

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Model(object):
    """
    Machine-learned Model.
    """

    #: A constant which can be used with the model_type property of a Model.
    #: This constant has a value of "IMAGE_CLASSIFICATION"
    MODEL_TYPE_IMAGE_CLASSIFICATION = "IMAGE_CLASSIFICATION"

    #: A constant which can be used with the model_type property of a Model.
    #: This constant has a value of "OBJECT_DETECTION"
    MODEL_TYPE_OBJECT_DETECTION = "OBJECT_DETECTION"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Model.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Model object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Model.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Model.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Model.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Model.
        :type compartment_id: str

        :param model_type:
            The value to assign to the model_type property of this Model.
            Allowed values for this property are: "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param is_quick_mode:
            The value to assign to the is_quick_mode property of this Model.
        :type is_quick_mode: bool

        :param max_training_duration_in_hours:
            The value to assign to the max_training_duration_in_hours property of this Model.
        :type max_training_duration_in_hours: float

        :param trained_duration_in_hours:
            The value to assign to the trained_duration_in_hours property of this Model.
        :type trained_duration_in_hours: float

        :param training_dataset:
            The value to assign to the training_dataset property of this Model.
        :type training_dataset: oci.ai_vision.models.Dataset

        :param testing_dataset:
            The value to assign to the testing_dataset property of this Model.
        :type testing_dataset: oci.ai_vision.models.Dataset

        :param validation_dataset:
            The value to assign to the validation_dataset property of this Model.
        :type validation_dataset: oci.ai_vision.models.Dataset

        :param model_version:
            The value to assign to the model_version property of this Model.
        :type model_version: str

        :param project_id:
            The value to assign to the project_id property of this Model.
        :type project_id: str

        :param time_created:
            The value to assign to the time_created property of this Model.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Model.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Model.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Model.
        :type lifecycle_details: str

        :param precision:
            The value to assign to the precision property of this Model.
        :type precision: float

        :param recall:
            The value to assign to the recall property of this Model.
        :type recall: float

        :param average_precision:
            The value to assign to the average_precision property of this Model.
        :type average_precision: float

        :param confidence_threshold:
            The value to assign to the confidence_threshold property of this Model.
        :type confidence_threshold: float

        :param total_image_count:
            The value to assign to the total_image_count property of this Model.
        :type total_image_count: int

        :param test_image_count:
            The value to assign to the test_image_count property of this Model.
        :type test_image_count: int

        :param metrics:
            The value to assign to the metrics property of this Model.
        :type metrics: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Model.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Model.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Model.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'model_type': 'str',
            'is_quick_mode': 'bool',
            'max_training_duration_in_hours': 'float',
            'trained_duration_in_hours': 'float',
            'training_dataset': 'Dataset',
            'testing_dataset': 'Dataset',
            'validation_dataset': 'Dataset',
            'model_version': 'str',
            'project_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'precision': 'float',
            'recall': 'float',
            'average_precision': 'float',
            'confidence_threshold': 'float',
            'total_image_count': 'int',
            'test_image_count': 'int',
            'metrics': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'model_type': 'modelType',
            'is_quick_mode': 'isQuickMode',
            'max_training_duration_in_hours': 'maxTrainingDurationInHours',
            'trained_duration_in_hours': 'trainedDurationInHours',
            'training_dataset': 'trainingDataset',
            'testing_dataset': 'testingDataset',
            'validation_dataset': 'validationDataset',
            'model_version': 'modelVersion',
            'project_id': 'projectId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'precision': 'precision',
            'recall': 'recall',
            'average_precision': 'averagePrecision',
            'confidence_threshold': 'confidenceThreshold',
            'total_image_count': 'totalImageCount',
            'test_image_count': 'testImageCount',
            'metrics': 'metrics',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }
        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._model_type = None
        self._is_quick_mode = None
        self._max_training_duration_in_hours = None
        self._trained_duration_in_hours = None
        self._training_dataset = None
        self._testing_dataset = None
        self._validation_dataset = None
        self._model_version = None
        self._project_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._precision = None
        self._recall = None
        self._average_precision = None
        self._confidence_threshold = None
        self._total_image_count = None
        self._test_image_count = None
        self._metrics = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Model.
        A unique identifier that is immutable after creation.


        :return: The id of this Model.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Model.
        A unique identifier that is immutable after creation.


        :param id: The id of this Model.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this Model.
        A human-friendly name for the model, which can be changed.


        :return: The display_name of this Model.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Model.
        A human-friendly name for the model, which can be changed.


        :param display_name: The display_name of this Model.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Model.
        An optional description of the model.


        :return: The description of this Model.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Model.
        An optional description of the model.


        :param description: The description of this Model.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Model.
        The compartment identifier.


        :return: The compartment_id of this Model.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Model.
        The compartment identifier.


        :param compartment_id: The compartment_id of this Model.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this Model.
        What type of Vision model this is.

        Allowed values for this property are: "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this Model.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this Model.
        What type of Vision model this is.


        :param model_type: The model_type of this Model.
        :type: str
        """
        allowed_values = ["IMAGE_CLASSIFICATION", "OBJECT_DETECTION"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def is_quick_mode(self):
        """
        Gets the is_quick_mode of this Model.
        Set to true when experimenting with a new model type or dataset, so model training is quick, with a predefined low number of passes through the training data.


        :return: The is_quick_mode of this Model.
        :rtype: bool
        """
        return self._is_quick_mode

    @is_quick_mode.setter
    def is_quick_mode(self, is_quick_mode):
        """
        Sets the is_quick_mode of this Model.
        Set to true when experimenting with a new model type or dataset, so model training is quick, with a predefined low number of passes through the training data.


        :param is_quick_mode: The is_quick_mode of this Model.
        :type: bool
        """
        self._is_quick_mode = is_quick_mode

    @property
    def max_training_duration_in_hours(self):
        """
        Gets the max_training_duration_in_hours of this Model.
        The maximum model training duration in hours, expressed as a decimal fraction.


        :return: The max_training_duration_in_hours of this Model.
        :rtype: float
        """
        return self._max_training_duration_in_hours

    @max_training_duration_in_hours.setter
    def max_training_duration_in_hours(self, max_training_duration_in_hours):
        """
        Sets the max_training_duration_in_hours of this Model.
        The maximum model training duration in hours, expressed as a decimal fraction.


        :param max_training_duration_in_hours: The max_training_duration_in_hours of this Model.
        :type: float
        """
        self._max_training_duration_in_hours = max_training_duration_in_hours

    @property
    def trained_duration_in_hours(self):
        """
        Gets the trained_duration_in_hours of this Model.
        The total hours actually used for model training.


        :return: The trained_duration_in_hours of this Model.
        :rtype: float
        """
        return self._trained_duration_in_hours

    @trained_duration_in_hours.setter
    def trained_duration_in_hours(self, trained_duration_in_hours):
        """
        Sets the trained_duration_in_hours of this Model.
        The total hours actually used for model training.


        :param trained_duration_in_hours: The trained_duration_in_hours of this Model.
        :type: float
        """
        self._trained_duration_in_hours = trained_duration_in_hours

    @property
    def training_dataset(self):
        """
        **[Required]** Gets the training_dataset of this Model.

        :return: The training_dataset of this Model.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._training_dataset

    @training_dataset.setter
    def training_dataset(self, training_dataset):
        """
        Sets the training_dataset of this Model.

        :param training_dataset: The training_dataset of this Model.
        :type: oci.ai_vision.models.Dataset
        """
        self._training_dataset = training_dataset

    @property
    def testing_dataset(self):
        """
        Gets the testing_dataset of this Model.

        :return: The testing_dataset of this Model.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._testing_dataset

    @testing_dataset.setter
    def testing_dataset(self, testing_dataset):
        """
        Sets the testing_dataset of this Model.

        :param testing_dataset: The testing_dataset of this Model.
        :type: oci.ai_vision.models.Dataset
        """
        self._testing_dataset = testing_dataset

    @property
    def validation_dataset(self):
        """
        Gets the validation_dataset of this Model.

        :return: The validation_dataset of this Model.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._validation_dataset

    @validation_dataset.setter
    def validation_dataset(self, validation_dataset):
        """
        Sets the validation_dataset of this Model.

        :param validation_dataset: The validation_dataset of this Model.
        :type: oci.ai_vision.models.Dataset
        """
        self._validation_dataset = validation_dataset

    @property
    def model_version(self):
        """
        **[Required]** Gets the model_version of this Model.
        The version of the model.


        :return: The model_version of this Model.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this Model.
        The version of the model.


        :param model_version: The model_version of this Model.
        :type: str
        """
        self._model_version = model_version

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this Model.
        The `OCID`__ of the project that contains the model.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The project_id of this Model.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this Model.
        The `OCID`__ of the project that contains the model.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param project_id: The project_id of this Model.
        :type: str
        """
        self._project_id = project_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Model.
        When the model was created, as an RFC3339 datetime string.


        :return: The time_created of this Model.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Model.
        When the model was created, as an RFC3339 datetime string.


        :param time_created: The time_created of this Model.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Model.
        When the model was updated, as an RFC3339 datetime string.


        :return: The time_updated of this Model.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Model.
        When the model was updated, as an RFC3339 datetime string.


        :param time_updated: The time_updated of this Model.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Model.
        The current state of the model.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Model.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Model.
        The current state of the model.


        :param lifecycle_state: The lifecycle_state of this Model.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Model.
        A message describing the current state in more detail, that can provide actionable information if training failed.


        :return: The lifecycle_details of this Model.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Model.
        A message describing the current state in more detail, that can provide actionable information if training failed.


        :param lifecycle_details: The lifecycle_details of this Model.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def precision(self):
        """
        Gets the precision of this Model.
        The precision of the trained model.


        :return: The precision of this Model.
        :rtype: float
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """
        Sets the precision of this Model.
        The precision of the trained model.


        :param precision: The precision of this Model.
        :type: float
        """
        self._precision = precision

    @property
    def recall(self):
        """
        Gets the recall of this Model.
        Recall of the trained model.


        :return: The recall of this Model.
        :rtype: float
        """
        return self._recall

    @recall.setter
    def recall(self, recall):
        """
        Sets the recall of this Model.
        Recall of the trained model.


        :param recall: The recall of this Model.
        :type: float
        """
        self._recall = recall

    @property
    def average_precision(self):
        """
        Gets the average_precision of this Model.
        The mean average precision of the trained model.


        :return: The average_precision of this Model.
        :rtype: float
        """
        return self._average_precision

    @average_precision.setter
    def average_precision(self, average_precision):
        """
        Sets the average_precision of this Model.
        The mean average precision of the trained model.


        :param average_precision: The average_precision of this Model.
        :type: float
        """
        self._average_precision = average_precision

    @property
    def confidence_threshold(self):
        """
        Gets the confidence_threshold of this Model.
        The intersection over the union threshold used for calculating precision and recall.


        :return: The confidence_threshold of this Model.
        :rtype: float
        """
        return self._confidence_threshold

    @confidence_threshold.setter
    def confidence_threshold(self, confidence_threshold):
        """
        Sets the confidence_threshold of this Model.
        The intersection over the union threshold used for calculating precision and recall.


        :param confidence_threshold: The confidence_threshold of this Model.
        :type: float
        """
        self._confidence_threshold = confidence_threshold

    @property
    def total_image_count(self):
        """
        Gets the total_image_count of this Model.
        The number of images in the dataset used to train, validate, and test the model.


        :return: The total_image_count of this Model.
        :rtype: int
        """
        return self._total_image_count

    @total_image_count.setter
    def total_image_count(self, total_image_count):
        """
        Sets the total_image_count of this Model.
        The number of images in the dataset used to train, validate, and test the model.


        :param total_image_count: The total_image_count of this Model.
        :type: int
        """
        self._total_image_count = total_image_count

    @property
    def test_image_count(self):
        """
        Gets the test_image_count of this Model.
        The number of images set aside for evaluating model performance metrics after training.


        :return: The test_image_count of this Model.
        :rtype: int
        """
        return self._test_image_count

    @test_image_count.setter
    def test_image_count(self, test_image_count):
        """
        Sets the test_image_count of this Model.
        The number of images set aside for evaluating model performance metrics after training.


        :param test_image_count: The test_image_count of this Model.
        :type: int
        """
        self._test_image_count = test_image_count

    @property
    def metrics(self):
        """
        Gets the metrics of this Model.
        The complete set of per-label metrics for successfully trained models.


        :return: The metrics of this Model.
        :rtype: str
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """
        Sets the metrics of this Model.
        The complete set of per-label metrics for successfully trained models.


        :param metrics: The metrics of this Model.
        :type: str
        """
        self._metrics = metrics

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Model.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Model.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Model.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Model.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Model.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Model.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Model.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Model.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Model.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        For example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this Model.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Model.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        For example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this Model.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateImageJobDetails(object):
    """
    The details of the batch image analysis.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateImageJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param input_location:
            The value to assign to the input_location property of this CreateImageJobDetails.
        :type input_location: oci.ai_vision.models.InputLocation

        :param features:
            The value to assign to the features property of this CreateImageJobDetails.
        :type features: list[oci.ai_vision.models.ImageFeature]

        :param output_location:
            The value to assign to the output_location property of this CreateImageJobDetails.
        :type output_location: oci.ai_vision.models.OutputLocation

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateImageJobDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateImageJobDetails.
        :type display_name: str

        :param is_zip_output_enabled:
            The value to assign to the is_zip_output_enabled property of this CreateImageJobDetails.
        :type is_zip_output_enabled: bool

        """
        self.swagger_types = {
            'input_location': 'InputLocation',
            'features': 'list[ImageFeature]',
            'output_location': 'OutputLocation',
            'compartment_id': 'str',
            'display_name': 'str',
            'is_zip_output_enabled': 'bool'
        }
        self.attribute_map = {
            'input_location': 'inputLocation',
            'features': 'features',
            'output_location': 'outputLocation',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'is_zip_output_enabled': 'isZipOutputEnabled'
        }
        self._input_location = None
        self._features = None
        self._output_location = None
        self._compartment_id = None
        self._display_name = None
        self._is_zip_output_enabled = None

    @property
    def input_location(self):
        """
        **[Required]** Gets the input_location of this CreateImageJobDetails.

        :return: The input_location of this CreateImageJobDetails.
        :rtype: oci.ai_vision.models.InputLocation
        """
        return self._input_location

    @input_location.setter
    def input_location(self, input_location):
        """
        Sets the input_location of this CreateImageJobDetails.

        :param input_location: The input_location of this CreateImageJobDetails.
        :type: oci.ai_vision.models.InputLocation
        """
        self._input_location = input_location

    @property
    def features(self):
        """
        **[Required]** Gets the features of this CreateImageJobDetails.
        The list of requested image analysis types.


        :return: The features of this CreateImageJobDetails.
        :rtype: list[oci.ai_vision.models.ImageFeature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this CreateImageJobDetails.
        The list of requested image analysis types.


        :param features: The features of this CreateImageJobDetails.
        :type: list[oci.ai_vision.models.ImageFeature]
        """
        self._features = features

    @property
    def output_location(self):
        """
        **[Required]** Gets the output_location of this CreateImageJobDetails.

        :return: The output_location of this CreateImageJobDetails.
        :rtype: oci.ai_vision.models.OutputLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this CreateImageJobDetails.

        :param output_location: The output_location of this CreateImageJobDetails.
        :type: oci.ai_vision.models.OutputLocation
        """
        self._output_location = output_location

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CreateImageJobDetails.
        The compartment identifier from the requester.


        :return: The compartment_id of this CreateImageJobDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateImageJobDetails.
        The compartment identifier from the requester.


        :param compartment_id: The compartment_id of this CreateImageJobDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateImageJobDetails.
        The image job display name.


        :return: The display_name of this CreateImageJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateImageJobDetails.
        The image job display name.


        :param display_name: The display_name of this CreateImageJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_zip_output_enabled(self):
        """
        Gets the is_zip_output_enabled of this CreateImageJobDetails.
        Whether or not to generate a ZIP file containing the results.


        :return: The is_zip_output_enabled of this CreateImageJobDetails.
        :rtype: bool
        """
        return self._is_zip_output_enabled

    @is_zip_output_enabled.setter
    def is_zip_output_enabled(self, is_zip_output_enabled):
        """
        Sets the is_zip_output_enabled of this CreateImageJobDetails.
        Whether or not to generate a ZIP file containing the results.


        :param is_zip_output_enabled: The is_zip_output_enabled of this CreateImageJobDetails.
        :type: bool
        """
        self._is_zip_output_enabled = is_zip_output_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoStreamFeature(object):
    """
    Details about a stream video feature request.
    """

    #: A constant which can be used with the feature_type property of a VideoStreamFeature.
    #: This constant has a value of "OBJECT_TRACKING"
    FEATURE_TYPE_OBJECT_TRACKING = "OBJECT_TRACKING"

    #: A constant which can be used with the feature_type property of a VideoStreamFeature.
    #: This constant has a value of "FACE_DETECTION"
    FEATURE_TYPE_FACE_DETECTION = "FACE_DETECTION"

    #: A constant which can be used with the feature_type property of a VideoStreamFeature.
    #: This constant has a value of "OBJECT_DETECTION"
    FEATURE_TYPE_OBJECT_DETECTION = "OBJECT_DETECTION"

    def __init__(self, **kwargs):
        """
        Initializes a new VideoStreamFeature object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.ai_vision.models.VideoStreamObjectTrackingFeature`
        * :class:`~oci.ai_vision.models.VideoStreamFaceDetectionFeature`
        * :class:`~oci.ai_vision.models.VideoStreamObjectDetectionFeature`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this VideoStreamFeature.
            Allowed values for this property are: "OBJECT_TRACKING", "FACE_DETECTION", "OBJECT_DETECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type feature_type: str

        """
        self.swagger_types = {
            'feature_type': 'str'
        }
        self.attribute_map = {
            'feature_type': 'featureType'
        }
        self._feature_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['featureType']

        if type == 'OBJECT_TRACKING':
            return 'VideoStreamObjectTrackingFeature'

        if type == 'FACE_DETECTION':
            return 'VideoStreamFaceDetectionFeature'

        if type == 'OBJECT_DETECTION':
            return 'VideoStreamObjectDetectionFeature'
        else:
            return 'VideoStreamFeature'

    @property
    def feature_type(self):
        """
        **[Required]** Gets the feature_type of this VideoStreamFeature.
        The feature of video analysis.
        Allowed values are:
        - OBJECT_TRACKING: Object tracking feature(OT).
        - FACE_DETECTION: Face detection feature(FD).
        - OBJECT_DETECTION: Object detection feature(OD)

        Allowed values for this property are: "OBJECT_TRACKING", "FACE_DETECTION", "OBJECT_DETECTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The feature_type of this VideoStreamFeature.
        :rtype: str
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        """
        Sets the feature_type of this VideoStreamFeature.
        The feature of video analysis.
        Allowed values are:
        - OBJECT_TRACKING: Object tracking feature(OT).
        - FACE_DETECTION: Face detection feature(FD).
        - OBJECT_DETECTION: Object detection feature(OD)


        :param feature_type: The feature_type of this VideoStreamFeature.
        :type: str
        """
        allowed_values = ["OBJECT_TRACKING", "FACE_DETECTION", "OBJECT_DETECTION"]
        if not value_allowed_none_or_none_sentinel(feature_type, allowed_values):
            feature_type = 'UNKNOWN_ENUM_VALUE'
        self._feature_type = feature_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Page(object):
    """
    One page document analysis result.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Page object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param page_number:
            The value to assign to the page_number property of this Page.
        :type page_number: int

        :param dimensions:
            The value to assign to the dimensions property of this Page.
        :type dimensions: oci.ai_vision.models.Dimensions

        :param detected_document_types:
            The value to assign to the detected_document_types property of this Page.
        :type detected_document_types: list[oci.ai_vision.models.DetectedDocumentType]

        :param detected_languages:
            The value to assign to the detected_languages property of this Page.
        :type detected_languages: list[oci.ai_vision.models.DetectedLanguage]

        :param words:
            The value to assign to the words property of this Page.
        :type words: list[oci.ai_vision.models.Word]

        :param lines:
            The value to assign to the lines property of this Page.
        :type lines: list[oci.ai_vision.models.Line]

        :param tables:
            The value to assign to the tables property of this Page.
        :type tables: list[oci.ai_vision.models.Table]

        :param document_fields:
            The value to assign to the document_fields property of this Page.
        :type document_fields: list[oci.ai_vision.models.DocumentField]

        """
        self.swagger_types = {
            'page_number': 'int',
            'dimensions': 'Dimensions',
            'detected_document_types': 'list[DetectedDocumentType]',
            'detected_languages': 'list[DetectedLanguage]',
            'words': 'list[Word]',
            'lines': 'list[Line]',
            'tables': 'list[Table]',
            'document_fields': 'list[DocumentField]'
        }
        self.attribute_map = {
            'page_number': 'pageNumber',
            'dimensions': 'dimensions',
            'detected_document_types': 'detectedDocumentTypes',
            'detected_languages': 'detectedLanguages',
            'words': 'words',
            'lines': 'lines',
            'tables': 'tables',
            'document_fields': 'documentFields'
        }
        self._page_number = None
        self._dimensions = None
        self._detected_document_types = None
        self._detected_languages = None
        self._words = None
        self._lines = None
        self._tables = None
        self._document_fields = None

    @property
    def page_number(self):
        """
        **[Required]** Gets the page_number of this Page.
        The document page number.


        :return: The page_number of this Page.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this Page.
        The document page number.


        :param page_number: The page_number of this Page.
        :type: int
        """
        self._page_number = page_number

    @property
    def dimensions(self):
        """
        Gets the dimensions of this Page.

        :return: The dimensions of this Page.
        :rtype: oci.ai_vision.models.Dimensions
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this Page.

        :param dimensions: The dimensions of this Page.
        :type: oci.ai_vision.models.Dimensions
        """
        self._dimensions = dimensions

    @property
    def detected_document_types(self):
        """
        Gets the detected_document_types of this Page.
        An array of detected document types.


        :return: The detected_document_types of this Page.
        :rtype: list[oci.ai_vision.models.DetectedDocumentType]
        """
        return self._detected_document_types

    @detected_document_types.setter
    def detected_document_types(self, detected_document_types):
        """
        Sets the detected_document_types of this Page.
        An array of detected document types.


        :param detected_document_types: The detected_document_types of this Page.
        :type: list[oci.ai_vision.models.DetectedDocumentType]
        """
        self._detected_document_types = detected_document_types

    @property
    def detected_languages(self):
        """
        Gets the detected_languages of this Page.
        An array of detected languages.


        :return: The detected_languages of this Page.
        :rtype: list[oci.ai_vision.models.DetectedLanguage]
        """
        return self._detected_languages

    @detected_languages.setter
    def detected_languages(self, detected_languages):
        """
        Sets the detected_languages of this Page.
        An array of detected languages.


        :param detected_languages: The detected_languages of this Page.
        :type: list[oci.ai_vision.models.DetectedLanguage]
        """
        self._detected_languages = detected_languages

    @property
    def words(self):
        """
        Gets the words of this Page.
        The words detected on the page.


        :return: The words of this Page.
        :rtype: list[oci.ai_vision.models.Word]
        """
        return self._words

    @words.setter
    def words(self, words):
        """
        Sets the words of this Page.
        The words detected on the page.


        :param words: The words of this Page.
        :type: list[oci.ai_vision.models.Word]
        """
        self._words = words

    @property
    def lines(self):
        """
        Gets the lines of this Page.
        The lines of text detected on the page.


        :return: The lines of this Page.
        :rtype: list[oci.ai_vision.models.Line]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """
        Sets the lines of this Page.
        The lines of text detected on the page.


        :param lines: The lines of this Page.
        :type: list[oci.ai_vision.models.Line]
        """
        self._lines = lines

    @property
    def tables(self):
        """
        Gets the tables of this Page.
        The tables detected on the page.


        :return: The tables of this Page.
        :rtype: list[oci.ai_vision.models.Table]
        """
        return self._tables

    @tables.setter
    def tables(self, tables):
        """
        Sets the tables of this Page.
        The tables detected on the page.


        :param tables: The tables of this Page.
        :type: list[oci.ai_vision.models.Table]
        """
        self._tables = tables

    @property
    def document_fields(self):
        """
        Gets the document_fields of this Page.
        The form fields detected on the page.


        :return: The document_fields of this Page.
        :rtype: list[oci.ai_vision.models.DocumentField]
        """
        return self._document_fields

    @document_fields.setter
    def document_fields(self, document_fields):
        """
        Sets the document_fields of this Page.
        The form fields detected on the page.


        :param document_fields: The document_fields of this Page.
        :type: list[oci.ai_vision.models.DocumentField]
        """
        self._document_fields = document_fields

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Dimensions(object):
    """
    The width and height of a page.
    """

    #: A constant which can be used with the unit property of a Dimensions.
    #: This constant has a value of "PIXEL"
    UNIT_PIXEL = "PIXEL"

    #: A constant which can be used with the unit property of a Dimensions.
    #: This constant has a value of "INCH"
    UNIT_INCH = "INCH"

    def __init__(self, **kwargs):
        """
        Initializes a new Dimensions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param width:
            The value to assign to the width property of this Dimensions.
        :type width: float

        :param height:
            The value to assign to the height property of this Dimensions.
        :type height: float

        :param unit:
            The value to assign to the unit property of this Dimensions.
            Allowed values for this property are: "PIXEL", "INCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type unit: str

        """
        self.swagger_types = {
            'width': 'float',
            'height': 'float',
            'unit': 'str'
        }
        self.attribute_map = {
            'width': 'width',
            'height': 'height',
            'unit': 'unit'
        }
        self._width = None
        self._height = None
        self._unit = None

    @property
    def width(self):
        """
        **[Required]** Gets the width of this Dimensions.
        the width of a page.


        :return: The width of this Dimensions.
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this Dimensions.
        the width of a page.


        :param width: The width of this Dimensions.
        :type: float
        """
        self._width = width

    @property
    def height(self):
        """
        **[Required]** Gets the height of this Dimensions.
        The height of a page.


        :return: The height of this Dimensions.
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this Dimensions.
        The height of a page.


        :param height: The height of this Dimensions.
        :type: float
        """
        self._height = height

    @property
    def unit(self):
        """
        **[Required]** Gets the unit of this Dimensions.
        The unit of length.

        Allowed values for this property are: "PIXEL", "INCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The unit of this Dimensions.
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """
        Sets the unit of this Dimensions.
        The unit of length.


        :param unit: The unit of this Dimensions.
        :type: str
        """
        allowed_values = ["PIXEL", "INCH"]
        if not value_allowed_none_or_none_sentinel(unit, allowed_values):
            unit = 'UNKNOWN_ENUM_VALUE'
        self._unit = unit

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .image_feature import ImageFeature
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageTextDetectionFeature(ImageFeature):
    """
    The text detection parameters.
    """

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "ENG"
    LANGUAGE_ENG = "ENG"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "CES"
    LANGUAGE_CES = "CES"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "DAN"
    LANGUAGE_DAN = "DAN"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "NLD"
    LANGUAGE_NLD = "NLD"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "FIN"
    LANGUAGE_FIN = "FIN"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "FRA"
    LANGUAGE_FRA = "FRA"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "DEU"
    LANGUAGE_DEU = "DEU"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "ELL"
    LANGUAGE_ELL = "ELL"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "HUN"
    LANGUAGE_HUN = "HUN"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "ITA"
    LANGUAGE_ITA = "ITA"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "NOR"
    LANGUAGE_NOR = "NOR"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "POL"
    LANGUAGE_POL = "POL"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "POR"
    LANGUAGE_POR = "POR"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "RON"
    LANGUAGE_RON = "RON"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "RUS"
    LANGUAGE_RUS = "RUS"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "SLK"
    LANGUAGE_SLK = "SLK"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "SPA"
    LANGUAGE_SPA = "SPA"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "SWE"
    LANGUAGE_SWE = "SWE"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "TUR"
    LANGUAGE_TUR = "TUR"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "ARA"
    LANGUAGE_ARA = "ARA"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "CHI_SIM"
    LANGUAGE_CHI_SIM = "CHI_SIM"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "HIN"
    LANGUAGE_HIN = "HIN"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "JPN"
    LANGUAGE_JPN = "JPN"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "KOR"
    LANGUAGE_KOR = "KOR"

    #: A constant which can be used with the language property of a ImageTextDetectionFeature.
    #: This constant has a value of "OTHERS"
    LANGUAGE_OTHERS = "OTHERS"

    def __init__(self, **kwargs):
        """
        Initializes a new ImageTextDetectionFeature object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.ImageTextDetectionFeature.feature_type` attribute
        of this class is ``TEXT_DETECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this ImageTextDetectionFeature.
            Allowed values for this property are: "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", "TEXT_DETECTION", "FACE_DETECTION", "FACE_EMBEDDING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type feature_type: str

        :param language:
            The value to assign to the language property of this ImageTextDetectionFeature.
            Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type language: str

        """
        self.swagger_types = {
            'feature_type': 'str',
            'language': 'str'
        }
        self.attribute_map = {
            'feature_type': 'featureType',
            'language': 'language'
        }
        self._feature_type = None
        self._language = None
        self._feature_type = 'TEXT_DETECTION'

    @property
    def language(self):
        """
        Gets the language of this ImageTextDetectionFeature.
        The language of the document image, abbreviated according to ISO 639-2.

        Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The language of this ImageTextDetectionFeature.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this ImageTextDetectionFeature.
        The language of the document image, abbreviated according to ISO 639-2.


        :param language: The language of this ImageTextDetectionFeature.
        :type: str
        """
        allowed_values = ["ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS"]
        if not value_allowed_none_or_none_sentinel(language, allowed_values):
            language = 'UNKNOWN_ENUM_VALUE'
        self._language = language

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoTrackingFrame(object):
    """
    A frame capturing a tracked object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoTrackingFrame object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_offset_ms:
            The value to assign to the time_offset_ms property of this VideoTrackingFrame.
        :type time_offset_ms: int

        :param confidence:
            The value to assign to the confidence property of this VideoTrackingFrame.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this VideoTrackingFrame.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        :param properties:
            The value to assign to the properties property of this VideoTrackingFrame.
        :type properties: list[oci.ai_vision.models.ObjectProperty]

        """
        self.swagger_types = {
            'time_offset_ms': 'int',
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon',
            'properties': 'list[ObjectProperty]'
        }
        self.attribute_map = {
            'time_offset_ms': 'timeOffsetMs',
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon',
            'properties': 'properties'
        }
        self._time_offset_ms = None
        self._confidence = None
        self._bounding_polygon = None
        self._properties = None

    @property
    def time_offset_ms(self):
        """
        **[Required]** Gets the time_offset_ms of this VideoTrackingFrame.
        Time offset(Milliseconds) of the frame.


        :return: The time_offset_ms of this VideoTrackingFrame.
        :rtype: int
        """
        return self._time_offset_ms

    @time_offset_ms.setter
    def time_offset_ms(self, time_offset_ms):
        """
        Sets the time_offset_ms of this VideoTrackingFrame.
        Time offset(Milliseconds) of the frame.


        :param time_offset_ms: The time_offset_ms of this VideoTrackingFrame.
        :type: int
        """
        self._time_offset_ms = time_offset_ms

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this VideoTrackingFrame.
        The confidence score, between 0 and 1.


        :return: The confidence of this VideoTrackingFrame.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this VideoTrackingFrame.
        The confidence score, between 0 and 1.


        :param confidence: The confidence of this VideoTrackingFrame.
        :type: float
        """
        self._confidence = confidence

    @property
    def bounding_polygon(self):
        """
        **[Required]** Gets the bounding_polygon of this VideoTrackingFrame.

        :return: The bounding_polygon of this VideoTrackingFrame.
        :rtype: oci.ai_vision.models.BoundingPolygon
        """
        return self._bounding_polygon

    @bounding_polygon.setter
    def bounding_polygon(self, bounding_polygon):
        """
        Sets the bounding_polygon of this VideoTrackingFrame.

        :param bounding_polygon: The bounding_polygon of this VideoTrackingFrame.
        :type: oci.ai_vision.models.BoundingPolygon
        """
        self._bounding_polygon = bounding_polygon

    @property
    def properties(self):
        """
        Gets the properties of this VideoTrackingFrame.
        Properties associated with the tracked object in the frame.


        :return: The properties of this VideoTrackingFrame.
        :rtype: list[oci.ai_vision.models.ObjectProperty]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this VideoTrackingFrame.
        Properties associated with the tracked object in the frame.


        :param properties: The properties of this VideoTrackingFrame.
        :type: list[oci.ai_vision.models.ObjectProperty]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TrackingType(object):
    """
    Details of what to track.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TrackingType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param objects:
            The value to assign to the objects property of this TrackingType.
        :type objects: list[str]

        :param detection_model_id:
            The value to assign to the detection_model_id property of this TrackingType.
        :type detection_model_id: str

        :param tracking_model_id:
            The value to assign to the tracking_model_id property of this TrackingType.
        :type tracking_model_id: str

        :param max_results:
            The value to assign to the max_results property of this TrackingType.
        :type max_results: int

        :param should_return_landmarks:
            The value to assign to the should_return_landmarks property of this TrackingType.
        :type should_return_landmarks: bool

        """
        self.swagger_types = {
            'objects': 'list[str]',
            'detection_model_id': 'str',
            'tracking_model_id': 'str',
            'max_results': 'int',
            'should_return_landmarks': 'bool'
        }
        self.attribute_map = {
            'objects': 'objects',
            'detection_model_id': 'detectionModelId',
            'tracking_model_id': 'trackingModelId',
            'max_results': 'maxResults',
            'should_return_landmarks': 'shouldReturnLandmarks'
        }
        self._objects = None
        self._detection_model_id = None
        self._tracking_model_id = None
        self._max_results = None
        self._should_return_landmarks = None

    @property
    def objects(self):
        """
        **[Required]** Gets the objects of this TrackingType.
        List of the objects to be tracked.


        :return: The objects of this TrackingType.
        :rtype: list[str]
        """
        return self._objects

    @objects.setter
    def objects(self, objects):
        """
        Sets the objects of this TrackingType.
        List of the objects to be tracked.


        :param objects: The objects of this TrackingType.
        :type: list[str]
        """
        self._objects = objects

    @property
    def detection_model_id(self):
        """
        Gets the detection_model_id of this TrackingType.
        The detection model OCID.


        :return: The detection_model_id of this TrackingType.
        :rtype: str
        """
        return self._detection_model_id

    @detection_model_id.setter
    def detection_model_id(self, detection_model_id):
        """
        Sets the detection_model_id of this TrackingType.
        The detection model OCID.


        :param detection_model_id: The detection_model_id of this TrackingType.
        :type: str
        """
        self._detection_model_id = detection_model_id

    @property
    def tracking_model_id(self):
        """
        Gets the tracking_model_id of this TrackingType.
        The tracking model OCID.


        :return: The tracking_model_id of this TrackingType.
        :rtype: str
        """
        return self._tracking_model_id

    @tracking_model_id.setter
    def tracking_model_id(self, tracking_model_id):
        """
        Sets the tracking_model_id of this TrackingType.
        The tracking model OCID.


        :param tracking_model_id: The tracking_model_id of this TrackingType.
        :type: str
        """
        self._tracking_model_id = tracking_model_id

    @property
    def max_results(self):
        """
        Gets the max_results of this TrackingType.
        The maximum number of results to return.


        :return: The max_results of this TrackingType.
        :rtype: int
        """
        return self._max_results

    @max_results.setter
    def max_results(self, max_results):
        """
        Sets the max_results of this TrackingType.
        The maximum number of results to return.


        :param max_results: The max_results of this TrackingType.
        :type: int
        """
        self._max_results = max_results

    @property
    def should_return_landmarks(self):
        """
        Gets the should_return_landmarks of this TrackingType.
        Whether or not return face landmarks.


        :return: The should_return_landmarks of this TrackingType.
        :rtype: bool
        """
        return self._should_return_landmarks

    @should_return_landmarks.setter
    def should_return_landmarks(self, should_return_landmarks):
        """
        Sets the should_return_landmarks of this TrackingType.
        Whether or not return face landmarks.


        :param should_return_landmarks: The should_return_landmarks of this TrackingType.
        :type: bool
        """
        self._should_return_landmarks = should_return_landmarks

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .video_stream_feature import VideoStreamFeature
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoStreamObjectTrackingFeature(VideoStreamFeature):
    """
    Video stream object tracking feature
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoStreamObjectTrackingFeature object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.VideoStreamObjectTrackingFeature.feature_type` attribute
        of this class is ``OBJECT_TRACKING`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this VideoStreamObjectTrackingFeature.
            Allowed values for this property are: "OBJECT_TRACKING", "FACE_DETECTION", "OBJECT_DETECTION"
        :type feature_type: str

        :param tracking_types:
            The value to assign to the tracking_types property of this VideoStreamObjectTrackingFeature.
        :type tracking_types: list[oci.ai_vision.models.TrackingType]

        """
        self.swagger_types = {
            'feature_type': 'str',
            'tracking_types': 'list[TrackingType]'
        }
        self.attribute_map = {
            'feature_type': 'featureType',
            'tracking_types': 'trackingTypes'
        }
        self._feature_type = None
        self._tracking_types = None
        self._feature_type = 'OBJECT_TRACKING'

    @property
    def tracking_types(self):
        """
        **[Required]** Gets the tracking_types of this VideoStreamObjectTrackingFeature.
        List of details of what to track.


        :return: The tracking_types of this VideoStreamObjectTrackingFeature.
        :rtype: list[oci.ai_vision.models.TrackingType]
        """
        return self._tracking_types

    @tracking_types.setter
    def tracking_types(self, tracking_types):
        """
        Sets the tracking_types of this VideoStreamObjectTrackingFeature.
        List of details of what to track.


        :param tracking_types: The tracking_types of this VideoStreamObjectTrackingFeature.
        :type: list[oci.ai_vision.models.TrackingType]
        """
        self._tracking_types = tracking_types

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyzeVideoStreamResult(object):
    """
    Video stream analysis results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyzeVideoStreamResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ontology_classes:
            The value to assign to the ontology_classes property of this AnalyzeVideoStreamResult.
        :type ontology_classes: oci.ai_vision.models.OntologyClass

        :param video_stream_metadata:
            The value to assign to the video_stream_metadata property of this AnalyzeVideoStreamResult.
        :type video_stream_metadata: oci.ai_vision.models.VideoStreamMetadata

        :param image_data:
            The value to assign to the image_data property of this AnalyzeVideoStreamResult.
        :type image_data: str

        :param stream_job_id:
            The value to assign to the stream_job_id property of this AnalyzeVideoStreamResult.
        :type stream_job_id: str

        :param stream_source_id:
            The value to assign to the stream_source_id property of this AnalyzeVideoStreamResult.
        :type stream_source_id: str

        :param timestamp:
            The value to assign to the timestamp property of this AnalyzeVideoStreamResult.
        :type timestamp: str

        :param video_stream_objects:
            The value to assign to the video_stream_objects property of this AnalyzeVideoStreamResult.
        :type video_stream_objects: list[oci.ai_vision.models.VideoStreamObject]

        :param object_tracking_model_versions:
            The value to assign to the object_tracking_model_versions property of this AnalyzeVideoStreamResult.
        :type object_tracking_model_versions: list[oci.ai_vision.models.ModelVersionDetails]

        :param object_detection_model_versions:
            The value to assign to the object_detection_model_versions property of this AnalyzeVideoStreamResult.
        :type object_detection_model_versions: list[oci.ai_vision.models.ModelVersionDetails]

        :param errors:
            The value to assign to the errors property of this AnalyzeVideoStreamResult.
        :type errors: list[oci.ai_vision.models.ProcessingError]

        """
        self.swagger_types = {
            'ontology_classes': 'OntologyClass',
            'video_stream_metadata': 'VideoStreamMetadata',
            'image_data': 'str',
            'stream_job_id': 'str',
            'stream_source_id': 'str',
            'timestamp': 'str',
            'video_stream_objects': 'list[VideoStreamObject]',
            'object_tracking_model_versions': 'list[ModelVersionDetails]',
            'object_detection_model_versions': 'list[ModelVersionDetails]',
            'errors': 'list[ProcessingError]'
        }
        self.attribute_map = {
            'ontology_classes': 'ontologyClasses',
            'video_stream_metadata': 'videoStreamMetadata',
            'image_data': 'imageData',
            'stream_job_id': 'streamJobId',
            'stream_source_id': 'streamSourceId',
            'timestamp': 'timestamp',
            'video_stream_objects': 'videoStreamObjects',
            'object_tracking_model_versions': 'objectTrackingModelVersions',
            'object_detection_model_versions': 'objectDetectionModelVersions',
            'errors': 'errors'
        }
        self._ontology_classes = None
        self._video_stream_metadata = None
        self._image_data = None
        self._stream_job_id = None
        self._stream_source_id = None
        self._timestamp = None
        self._video_stream_objects = None
        self._object_tracking_model_versions = None
        self._object_detection_model_versions = None
        self._errors = None

    @property
    def ontology_classes(self):
        """
        Gets the ontology_classes of this AnalyzeVideoStreamResult.

        :return: The ontology_classes of this AnalyzeVideoStreamResult.
        :rtype: oci.ai_vision.models.OntologyClass
        """
        return self._ontology_classes

    @ontology_classes.setter
    def ontology_classes(self, ontology_classes):
        """
        Sets the ontology_classes of this AnalyzeVideoStreamResult.

        :param ontology_classes: The ontology_classes of this AnalyzeVideoStreamResult.
        :type: oci.ai_vision.models.OntologyClass
        """
        self._ontology_classes = ontology_classes

    @property
    def video_stream_metadata(self):
        """
        **[Required]** Gets the video_stream_metadata of this AnalyzeVideoStreamResult.

        :return: The video_stream_metadata of this AnalyzeVideoStreamResult.
        :rtype: oci.ai_vision.models.VideoStreamMetadata
        """
        return self._video_stream_metadata

    @video_stream_metadata.setter
    def video_stream_metadata(self, video_stream_metadata):
        """
        Sets the video_stream_metadata of this AnalyzeVideoStreamResult.

        :param video_stream_metadata: The video_stream_metadata of this AnalyzeVideoStreamResult.
        :type: oci.ai_vision.models.VideoStreamMetadata
        """
        self._video_stream_metadata = video_stream_metadata

    @property
    def image_data(self):
        """
        Gets the image_data of this AnalyzeVideoStreamResult.
        Base 64 encoded frame


        :return: The image_data of this AnalyzeVideoStreamResult.
        :rtype: str
        """
        return self._image_data

    @image_data.setter
    def image_data(self, image_data):
        """
        Sets the image_data of this AnalyzeVideoStreamResult.
        Base 64 encoded frame


        :param image_data: The image_data of this AnalyzeVideoStreamResult.
        :type: str
        """
        self._image_data = image_data

    @property
    def stream_job_id(self):
        """
        **[Required]** Gets the stream_job_id of this AnalyzeVideoStreamResult.
        `OCID`__ of streamJob.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stream_job_id of this AnalyzeVideoStreamResult.
        :rtype: str
        """
        return self._stream_job_id

    @stream_job_id.setter
    def stream_job_id(self, stream_job_id):
        """
        Sets the stream_job_id of this AnalyzeVideoStreamResult.
        `OCID`__ of streamJob.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stream_job_id: The stream_job_id of this AnalyzeVideoStreamResult.
        :type: str
        """
        self._stream_job_id = stream_job_id

    @property
    def stream_source_id(self):
        """
        **[Required]** Gets the stream_source_id of this AnalyzeVideoStreamResult.
        `OCID`__ of StreamSource.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stream_source_id of this AnalyzeVideoStreamResult.
        :rtype: str
        """
        return self._stream_source_id

    @stream_source_id.setter
    def stream_source_id(self, stream_source_id):
        """
        Sets the stream_source_id of this AnalyzeVideoStreamResult.
        `OCID`__ of StreamSource.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stream_source_id: The stream_source_id of this AnalyzeVideoStreamResult.
        :type: str
        """
        self._stream_source_id = stream_source_id

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this AnalyzeVideoStreamResult.
        time stamp of frame in utc.


        :return: The timestamp of this AnalyzeVideoStreamResult.
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this AnalyzeVideoStreamResult.
        time stamp of frame in utc.


        :param timestamp: The timestamp of this AnalyzeVideoStreamResult.
        :type: str
        """
        self._timestamp = timestamp

    @property
    def video_stream_objects(self):
        """
        Gets the video_stream_objects of this AnalyzeVideoStreamResult.
        Tracked objects in a video stream.


        :return: The video_stream_objects of this AnalyzeVideoStreamResult.
        :rtype: list[oci.ai_vision.models.VideoStreamObject]
        """
        return self._video_stream_objects

    @video_stream_objects.setter
    def video_stream_objects(self, video_stream_objects):
        """
        Sets the video_stream_objects of this AnalyzeVideoStreamResult.
        Tracked objects in a video stream.


        :param video_stream_objects: The video_stream_objects of this AnalyzeVideoStreamResult.
        :type: list[oci.ai_vision.models.VideoStreamObject]
        """
        self._video_stream_objects = video_stream_objects

    @property
    def object_tracking_model_versions(self):
        """
        Gets the object_tracking_model_versions of this AnalyzeVideoStreamResult.
        List of Object Tracking model versions.


        :return: The object_tracking_model_versions of this AnalyzeVideoStreamResult.
        :rtype: list[oci.ai_vision.models.ModelVersionDetails]
        """
        return self._object_tracking_model_versions

    @object_tracking_model_versions.setter
    def object_tracking_model_versions(self, object_tracking_model_versions):
        """
        Sets the object_tracking_model_versions of this AnalyzeVideoStreamResult.
        List of Object Tracking model versions.


        :param object_tracking_model_versions: The object_tracking_model_versions of this AnalyzeVideoStreamResult.
        :type: list[oci.ai_vision.models.ModelVersionDetails]
        """
        self._object_tracking_model_versions = object_tracking_model_versions

    @property
    def object_detection_model_versions(self):
        """
        Gets the object_detection_model_versions of this AnalyzeVideoStreamResult.
        List of Object Detection model versions.


        :return: The object_detection_model_versions of this AnalyzeVideoStreamResult.
        :rtype: list[oci.ai_vision.models.ModelVersionDetails]
        """
        return self._object_detection_model_versions

    @object_detection_model_versions.setter
    def object_detection_model_versions(self, object_detection_model_versions):
        """
        Sets the object_detection_model_versions of this AnalyzeVideoStreamResult.
        List of Object Detection model versions.


        :param object_detection_model_versions: The object_detection_model_versions of this AnalyzeVideoStreamResult.
        :type: list[oci.ai_vision.models.ModelVersionDetails]
        """
        self._object_detection_model_versions = object_detection_model_versions

    @property
    def errors(self):
        """
        Gets the errors of this AnalyzeVideoStreamResult.
        Array of possible errors.


        :return: The errors of this AnalyzeVideoStreamResult.
        :rtype: list[oci.ai_vision.models.ProcessingError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this AnalyzeVideoStreamResult.
        Array of possible errors.


        :param errors: The errors of this AnalyzeVideoStreamResult.
        :type: list[oci.ai_vision.models.ProcessingError]
        """
        self._errors = errors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .document_details import DocumentDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InlineDocumentDetails(DocumentDetails):
    """
    The document incorporated in the request payload.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InlineDocumentDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.InlineDocumentDetails.source` attribute
        of this class is ``INLINE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this InlineDocumentDetails.
            Allowed values for this property are: "INLINE", "OBJECT_STORAGE"
        :type source: str

        :param data:
            The value to assign to the data property of this InlineDocumentDetails.
        :type data: str

        """
        self.swagger_types = {
            'source': 'str',
            'data': 'str'
        }
        self.attribute_map = {
            'source': 'source',
            'data': 'data'
        }
        self._source = None
        self._data = None
        self._source = 'INLINE'

    @property
    def data(self):
        """
        **[Required]** Gets the data of this InlineDocumentDetails.
        Raw document data.


        :return: The data of this InlineDocumentDetails.
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this InlineDocumentDetails.
        Raw document data.


        :param data: The data of this InlineDocumentDetails.
        :type: str
        """
        self._data = data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StreamGroupOverlap(object):
    """
    List of streamSource OCIDs that have overlapping fields of view
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StreamGroupOverlap object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param overlapping_streams:
            The value to assign to the overlapping_streams property of this StreamGroupOverlap.
        :type overlapping_streams: list[str]

        """
        self.swagger_types = {
            'overlapping_streams': 'list[str]'
        }
        self.attribute_map = {
            'overlapping_streams': 'overlappingStreams'
        }
        self._overlapping_streams = None

    @property
    def overlapping_streams(self):
        """
        Gets the overlapping_streams of this StreamGroupOverlap.
        List of streamSource OCIDs.


        :return: The overlapping_streams of this StreamGroupOverlap.
        :rtype: list[str]
        """
        return self._overlapping_streams

    @overlapping_streams.setter
    def overlapping_streams(self, overlapping_streams):
        """
        Sets the overlapping_streams of this StreamGroupOverlap.
        List of streamSource OCIDs.


        :param overlapping_streams: The overlapping_streams of this StreamGroupOverlap.
        :type: list[str]
        """
        self._overlapping_streams = overlapping_streams

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NormalizedVertex(object):
    """
    An (x, y) coordinate in the image with dimensions normalized from zero to one.
    The origin is at top left, with the positive x-axis pointing right and the positive y-axis pointing down.
    The bottom right corner is at (1, 1).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NormalizedVertex object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param x:
            The value to assign to the x property of this NormalizedVertex.
        :type x: float

        :param y:
            The value to assign to the y property of this NormalizedVertex.
        :type y: float

        """
        self.swagger_types = {
            'x': 'float',
            'y': 'float'
        }
        self.attribute_map = {
            'x': 'x',
            'y': 'y'
        }
        self._x = None
        self._y = None

    @property
    def x(self):
        """
        **[Required]** Gets the x of this NormalizedVertex.
        The X-axis normalized coordinate.


        :return: The x of this NormalizedVertex.
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this NormalizedVertex.
        The X-axis normalized coordinate.


        :param x: The x of this NormalizedVertex.
        :type: float
        """
        self._x = x

    @property
    def y(self):
        """
        **[Required]** Gets the y of this NormalizedVertex.
        The Y-axis normalized coordinate.


        :return: The y of this NormalizedVertex.
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this NormalizedVertex.
        The Y-axis normalized coordinate.


        :param y: The y of this NormalizedVertex.
        :type: float
        """
        self._y = y

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoTrackedObject(object):
    """
    Tracked object in a video.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoTrackedObject object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this VideoTrackedObject.
        :type name: str

        :param object_id:
            The value to assign to the object_id property of this VideoTrackedObject.
        :type object_id: int

        :param properties:
            The value to assign to the properties property of this VideoTrackedObject.
        :type properties: oci.ai_vision.models.VideoTrackedObjectProperties

        :param segments:
            The value to assign to the segments property of this VideoTrackedObject.
        :type segments: list[oci.ai_vision.models.VideoTrackedObjectSegment]

        """
        self.swagger_types = {
            'name': 'str',
            'object_id': 'int',
            'properties': 'VideoTrackedObjectProperties',
            'segments': 'list[VideoTrackedObjectSegment]'
        }
        self.attribute_map = {
            'name': 'name',
            'object_id': 'objectId',
            'properties': 'properties',
            'segments': 'segments'
        }
        self._name = None
        self._object_id = None
        self._properties = None
        self._segments = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this VideoTrackedObject.
        Name of the object category label.


        :return: The name of this VideoTrackedObject.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VideoTrackedObject.
        Name of the object category label.


        :param name: The name of this VideoTrackedObject.
        :type: str
        """
        self._name = name

    @property
    def object_id(self):
        """
        **[Required]** Gets the object_id of this VideoTrackedObject.
        Unique identifier for the object.


        :return: The object_id of this VideoTrackedObject.
        :rtype: int
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """
        Sets the object_id of this VideoTrackedObject.
        Unique identifier for the object.


        :param object_id: The object_id of this VideoTrackedObject.
        :type: int
        """
        self._object_id = object_id

    @property
    def properties(self):
        """
        Gets the properties of this VideoTrackedObject.

        :return: The properties of this VideoTrackedObject.
        :rtype: oci.ai_vision.models.VideoTrackedObjectProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this VideoTrackedObject.

        :param properties: The properties of this VideoTrackedObject.
        :type: oci.ai_vision.models.VideoTrackedObjectProperties
        """
        self._properties = properties

    @property
    def segments(self):
        """
        **[Required]** Gets the segments of this VideoTrackedObject.
        Segments for the tracked object.


        :return: The segments of this VideoTrackedObject.
        :rtype: list[oci.ai_vision.models.VideoTrackedObjectSegment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this VideoTrackedObject.
        Segments for the tracked object.


        :param segments: The segments of this VideoTrackedObject.
        :type: list[oci.ai_vision.models.VideoTrackedObjectSegment]
        """
        self._segments = segments

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from __future__ import absolute_import

from .analyze_document_details import AnalyzeDocumentDetails
from .analyze_document_result import AnalyzeDocumentResult
from .analyze_image_details import AnalyzeImageDetails
from .analyze_image_result import AnalyzeImageResult
from .analyze_video_result import AnalyzeVideoResult
from .analyze_video_stream_result import AnalyzeVideoStreamResult
from .bounding_polygon import BoundingPolygon
from .cell import Cell
from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .change_stream_group_compartment_details import ChangeStreamGroupCompartmentDetails
from .change_stream_job_compartment_details import ChangeStreamJobCompartmentDetails
from .change_stream_source_compartment_details import ChangeStreamSourceCompartmentDetails
from .change_vision_private_endpoint_compartment_details import ChangeVisionPrivateEndpointCompartmentDetails
from .create_document_job_details import CreateDocumentJobDetails
from .create_image_job_details import CreateImageJobDetails
from .create_model_details import CreateModelDetails
from .create_project_details import CreateProjectDetails
from .create_stream_group_details import CreateStreamGroupDetails
from .create_stream_job_details import CreateStreamJobDetails
from .create_stream_source_details import CreateStreamSourceDetails
from .create_video_job_details import CreateVideoJobDetails
from .create_vision_private_endpoint_details import CreateVisionPrivateEndpointDetails
from .data_science_labeling_dataset import DataScienceLabelingDataset
from .dataset import Dataset
from .detected_document_type import DetectedDocumentType
from .detected_language import DetectedLanguage
from .dimensions import Dimensions
from .document_classification_feature import DocumentClassificationFeature
from .document_details import DocumentDetails
from .document_feature import DocumentFeature
from .document_field import DocumentField
from .document_job import DocumentJob
from .document_key_value_detection_feature import DocumentKeyValueDetectionFeature
from .document_language_classification_feature import DocumentLanguageClassificationFeature
from .document_metadata import DocumentMetadata
from .document_table_detection_feature import DocumentTableDetectionFeature
from .document_text_detection_feature import DocumentTextDetectionFeature
from .face import Face
from .face_detection_feature import FaceDetectionFeature
from .face_embedding_feature import FaceEmbeddingFeature
from .field_label import FieldLabel
from .field_name import FieldName
from .field_value import FieldValue
from .image_classification_feature import ImageClassificationFeature
from .image_details import ImageDetails
from .image_feature import ImageFeature
from .image_job import ImageJob
from .image_object import ImageObject
from .image_object_detection_feature import ImageObjectDetectionFeature
from .image_text import ImageText
from .image_text_detection_feature import ImageTextDetectionFeature
from .inline_document_details import InlineDocumentDetails
from .inline_image_details import InlineImageDetails
from .input_location import InputLocation
from .label import Label
from .landmark import Landmark
from .line import Line
from .model import Model
from .model_collection import ModelCollection
from .model_summary import ModelSummary
from .model_version_details import ModelVersionDetails
from .normalized_vertex import NormalizedVertex
from .object_list_inline_input_location import ObjectListInlineInputLocation
from .object_location import ObjectLocation
from .object_properties import ObjectProperties
from .object_property import ObjectProperty
from .object_storage_dataset import ObjectStorageDataset
from .object_storage_document_details import ObjectStorageDocumentDetails
from .object_storage_image_details import ObjectStorageImageDetails
from .object_storage_output_location import ObjectStorageOutputLocation
from .ontology_class import OntologyClass
from .output_location import OutputLocation
from .page import Page
from .private_stream_network_access_details import PrivateStreamNetworkAccessDetails
from .processing_error import ProcessingError
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .rtsp_source_details import RtspSourceDetails
from .stream_group import StreamGroup
from .stream_group_collection import StreamGroupCollection
from .stream_group_overlap import StreamGroupOverlap
from .stream_group_summary import StreamGroupSummary
from .stream_job import StreamJob
from .stream_job_collection import StreamJobCollection
from .stream_job_summary import StreamJobSummary
from .stream_network_access_details import StreamNetworkAccessDetails
from .stream_output_location import StreamOutputLocation
from .stream_source import StreamSource
from .stream_source_collection import StreamSourceCollection
from .stream_source_details import StreamSourceDetails
from .stream_source_summary import StreamSourceSummary
from .table import Table
from .table_row import TableRow
from .tracking_type import TrackingType
from .update_model_details import UpdateModelDetails
from .update_project_details import UpdateProjectDetails
from .update_stream_group_details import UpdateStreamGroupDetails
from .update_stream_job_details import UpdateStreamJobDetails
from .update_stream_source_details import UpdateStreamSourceDetails
from .update_vision_private_endpoint_details import UpdateVisionPrivateEndpointDetails
from .value_array import ValueArray
from .value_date import ValueDate
from .value_integer import ValueInteger
from .value_number import ValueNumber
from .value_phone_number import ValuePhoneNumber
from .value_string import ValueString
from .value_time import ValueTime
from .video_face import VideoFace
from .video_face_detection_feature import VideoFaceDetectionFeature
from .video_face_frame import VideoFaceFrame
from .video_face_segment import VideoFaceSegment
from .video_feature import VideoFeature
from .video_job import VideoJob
from .video_label import VideoLabel
from .video_label_detection_feature import VideoLabelDetectionFeature
from .video_label_segment import VideoLabelSegment
from .video_metadata import VideoMetadata
from .video_object import VideoObject
from .video_object_detection_feature import VideoObjectDetectionFeature
from .video_object_frame import VideoObjectFrame
from .video_object_segment import VideoObjectSegment
from .video_object_tracking_feature import VideoObjectTrackingFeature
from .video_segment import VideoSegment
from .video_stream_face_detection_feature import VideoStreamFaceDetectionFeature
from .video_stream_feature import VideoStreamFeature
from .video_stream_metadata import VideoStreamMetadata
from .video_stream_object import VideoStreamObject
from .video_stream_object_detection_feature import VideoStreamObjectDetectionFeature
from .video_stream_object_tracking_feature import VideoStreamObjectTrackingFeature
from .video_text import VideoText
from .video_text_detection_feature import VideoTextDetectionFeature
from .video_text_frame import VideoTextFrame
from .video_text_segment import VideoTextSegment
from .video_tracked_object import VideoTrackedObject
from .video_tracked_object_properties import VideoTrackedObjectProperties
from .video_tracked_object_segment import VideoTrackedObjectSegment
from .video_tracking_frame import VideoTrackingFrame
from .vision_private_endpoint import VisionPrivateEndpoint
from .vision_private_endpoint_collection import VisionPrivateEndpointCollection
from .vision_private_endpoint_summary import VisionPrivateEndpointSummary
from .word import Word
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for ai_vision services.
ai_vision_type_mapping = {
    "AnalyzeDocumentDetails": AnalyzeDocumentDetails,
    "AnalyzeDocumentResult": AnalyzeDocumentResult,
    "AnalyzeImageDetails": AnalyzeImageDetails,
    "AnalyzeImageResult": AnalyzeImageResult,
    "AnalyzeVideoResult": AnalyzeVideoResult,
    "AnalyzeVideoStreamResult": AnalyzeVideoStreamResult,
    "BoundingPolygon": BoundingPolygon,
    "Cell": Cell,
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "ChangeStreamGroupCompartmentDetails": ChangeStreamGroupCompartmentDetails,
    "ChangeStreamJobCompartmentDetails": ChangeStreamJobCompartmentDetails,
    "ChangeStreamSourceCompartmentDetails": ChangeStreamSourceCompartmentDetails,
    "ChangeVisionPrivateEndpointCompartmentDetails": ChangeVisionPrivateEndpointCompartmentDetails,
    "CreateDocumentJobDetails": CreateDocumentJobDetails,
    "CreateImageJobDetails": CreateImageJobDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "CreateStreamGroupDetails": CreateStreamGroupDetails,
    "CreateStreamJobDetails": CreateStreamJobDetails,
    "CreateStreamSourceDetails": CreateStreamSourceDetails,
    "CreateVideoJobDetails": CreateVideoJobDetails,
    "CreateVisionPrivateEndpointDetails": CreateVisionPrivateEndpointDetails,
    "DataScienceLabelingDataset": DataScienceLabelingDataset,
    "Dataset": Dataset,
    "DetectedDocumentType": DetectedDocumentType,
    "DetectedLanguage": DetectedLanguage,
    "Dimensions": Dimensions,
    "DocumentClassificationFeature": DocumentClassificationFeature,
    "DocumentDetails": DocumentDetails,
    "DocumentFeature": DocumentFeature,
    "DocumentField": DocumentField,
    "DocumentJob": DocumentJob,
    "DocumentKeyValueDetectionFeature": DocumentKeyValueDetectionFeature,
    "DocumentLanguageClassificationFeature": DocumentLanguageClassificationFeature,
    "DocumentMetadata": DocumentMetadata,
    "DocumentTableDetectionFeature": DocumentTableDetectionFeature,
    "DocumentTextDetectionFeature": DocumentTextDetectionFeature,
    "Face": Face,
    "FaceDetectionFeature": FaceDetectionFeature,
    "FaceEmbeddingFeature": FaceEmbeddingFeature,
    "FieldLabel": FieldLabel,
    "FieldName": FieldName,
    "FieldValue": FieldValue,
    "ImageClassificationFeature": ImageClassificationFeature,
    "ImageDetails": ImageDetails,
    "ImageFeature": ImageFeature,
    "ImageJob": ImageJob,
    "ImageObject": ImageObject,
    "ImageObjectDetectionFeature": ImageObjectDetectionFeature,
    "ImageText": ImageText,
    "ImageTextDetectionFeature": ImageTextDetectionFeature,
    "InlineDocumentDetails": InlineDocumentDetails,
    "InlineImageDetails": InlineImageDetails,
    "InputLocation": InputLocation,
    "Label": Label,
    "Landmark": Landmark,
    "Line": Line,
    "Model": Model,
    "ModelCollection": ModelCollection,
    "ModelSummary": ModelSummary,
    "ModelVersionDetails": ModelVersionDetails,
    "NormalizedVertex": NormalizedVertex,
    "ObjectListInlineInputLocation": ObjectListInlineInputLocation,
    "ObjectLocation": ObjectLocation,
    "ObjectProperties": ObjectProperties,
    "ObjectProperty": ObjectProperty,
    "ObjectStorageDataset": ObjectStorageDataset,
    "ObjectStorageDocumentDetails": ObjectStorageDocumentDetails,
    "ObjectStorageImageDetails": ObjectStorageImageDetails,
    "ObjectStorageOutputLocation": ObjectStorageOutputLocation,
    "OntologyClass": OntologyClass,
    "OutputLocation": OutputLocation,
    "Page": Page,
    "PrivateStreamNetworkAccessDetails": PrivateStreamNetworkAccessDetails,
    "ProcessingError": ProcessingError,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "RtspSourceDetails": RtspSourceDetails,
    "StreamGroup": StreamGroup,
    "StreamGroupCollection": StreamGroupCollection,
    "StreamGroupOverlap": StreamGroupOverlap,
    "StreamGroupSummary": StreamGroupSummary,
    "StreamJob": StreamJob,
    "StreamJobCollection": StreamJobCollection,
    "StreamJobSummary": StreamJobSummary,
    "StreamNetworkAccessDetails": StreamNetworkAccessDetails,
    "StreamOutputLocation": StreamOutputLocation,
    "StreamSource": StreamSource,
    "StreamSourceCollection": StreamSourceCollection,
    "StreamSourceDetails": StreamSourceDetails,
    "StreamSourceSummary": StreamSourceSummary,
    "Table": Table,
    "TableRow": TableRow,
    "TrackingType": TrackingType,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateStreamGroupDetails": UpdateStreamGroupDetails,
    "UpdateStreamJobDetails": UpdateStreamJobDetails,
    "UpdateStreamSourceDetails": UpdateStreamSourceDetails,
    "UpdateVisionPrivateEndpointDetails": UpdateVisionPrivateEndpointDetails,
    "ValueArray": ValueArray,
    "ValueDate": ValueDate,
    "ValueInteger": ValueInteger,
    "ValueNumber": ValueNumber,
    "ValuePhoneNumber": ValuePhoneNumber,
    "ValueString": ValueString,
    "ValueTime": ValueTime,
    "VideoFace": VideoFace,
    "VideoFaceDetectionFeature": VideoFaceDetectionFeature,
    "VideoFaceFrame": VideoFaceFrame,
    "VideoFaceSegment": VideoFaceSegment,
    "VideoFeature": VideoFeature,
    "VideoJob": VideoJob,
    "VideoLabel": VideoLabel,
    "VideoLabelDetectionFeature": VideoLabelDetectionFeature,
    "VideoLabelSegment": VideoLabelSegment,
    "VideoMetadata": VideoMetadata,
    "VideoObject": VideoObject,
    "VideoObjectDetectionFeature": VideoObjectDetectionFeature,
    "VideoObjectFrame": VideoObjectFrame,
    "VideoObjectSegment": VideoObjectSegment,
    "VideoObjectTrackingFeature": VideoObjectTrackingFeature,
    "VideoSegment": VideoSegment,
    "VideoStreamFaceDetectionFeature": VideoStreamFaceDetectionFeature,
    "VideoStreamFeature": VideoStreamFeature,
    "VideoStreamMetadata": VideoStreamMetadata,
    "VideoStreamObject": VideoStreamObject,
    "VideoStreamObjectDetectionFeature": VideoStreamObjectDetectionFeature,
    "VideoStreamObjectTrackingFeature": VideoStreamObjectTrackingFeature,
    "VideoText": VideoText,
    "VideoTextDetectionFeature": VideoTextDetectionFeature,
    "VideoTextFrame": VideoTextFrame,
    "VideoTextSegment": VideoTextSegment,
    "VideoTrackedObject": VideoTrackedObject,
    "VideoTrackedObjectProperties": VideoTrackedObjectProperties,
    "VideoTrackedObjectSegment": VideoTrackedObjectSegment,
    "VideoTrackingFrame": VideoTrackingFrame,
    "VisionPrivateEndpoint": VisionPrivateEndpoint,
    "VisionPrivateEndpointCollection": VisionPrivateEndpointCollection,
    "VisionPrivateEndpointSummary": VisionPrivateEndpointSummary,
    "Word": Word,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}
